@@ -122,7 +122,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 			USER_MESSAGES_NOTIFICATIONS,              // Column Family Name
 			StringSerializer.get(),   // Key Serializer
 			StringSerializer.get());  // Column Serializer
-	private static ColumnFamily<String, String> cf_UserNotificationsPreferences =	new ColumnFamily<String, String>(
+	protected static ColumnFamily<String, String> cf_UserNotificationsPreferences =	new ColumnFamily<String, String>(
 			USER_NOTIFICATIONS_PREFERENCES,  // Column Family Name
 			StringSerializer.get(),   // Key Serializer
 			StringSerializer.get());  // Column Serializer
@@ -133,6 +133,10 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 	 * connection instance
 	 */
 	private CassandraClusterConnection conn;
+	
+	protected CassandraClusterConnection getConnection() {
+		return conn;
+	}
 	/**
 	 * use this constructor carefully from test classes
 	 * @param dropSchema set true if you want do drop the current and set up new one
@@ -641,20 +645,20 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		} 
 		ArrayList<Feed> feedsToReturn = new ArrayList<Feed>();
 		ArrayList<String> feedIDs = getVREFeedIds(vreid);
-		
+
 		//if from is greater than feeds size return empty
 		if (from >=  feedIDs.size()) {
 			_log.warn("The starting point of the range is greather than the total number of feeds for this timeline: " + from + " >= " + feedIDs.size());
 			return new RangeFeeds();
 		}
-		
+
 		int rangeStart = feedIDs.size()-from;
 		int rangeEnd = rangeStart-quantity;
-		
+
 		//check that you reached the end
 		if (rangeEnd<1)
 			rangeEnd = 0;
-		
+
 		_log.debug("BEFORE starting Point=" + rangeStart + " rangeEnd= " + rangeEnd);
 		//need them in reverse order		
 		int howMany = from;
@@ -885,20 +889,20 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		} 
 		ArrayList<Notification> toReturn = new ArrayList<Notification>();
 		ArrayList<String> notificationsIDs = getUserNotificationsIds(userid);
-		
+
 		//if from is greater than feeds size return empty
 		if (from >=  notificationsIDs.size()) {
 			_log.warn("The starting point of the range is greather than the total number of feeds for this timeline: " + from + " >= " + notificationsIDs.size());
 			return new  ArrayList<Notification>();
 		}
-		
+
 		int rangeStart = notificationsIDs.size()-from;
 		int rangeEnd = rangeStart-quantity;
-		
+
 		//check that you reached the end
 		if (rangeEnd<1)
 			rangeEnd = 0;
-		
+
 		_log.debug("BEFORE starting Point=" + rangeStart + " rangeEnd= " + rangeEnd);
 		//need them in reverse order		
 		for (int i = rangeStart; i > rangeEnd; i--) {
@@ -994,7 +998,10 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		if (toProcess == null) {
 			_log.warn("Single Notification preference of  " + userid +  " Type: " + notificationType + " not existing ... creating default");
 			return createNewNotificationType(userid, notificationType);
-		} else
+		}
+		else if (toProcess.length == 0) 
+			return toReturn;
+		else
 			for (int i = 0; i < toProcess.length; i++) {
 				toReturn.add(toProcess[i]);
 			}
@@ -1009,7 +1016,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		MutationBatch m = conn.getKeyspace().prepareMutationBatch();
 		String valueToInsert = "";
 		NotificationChannelType[] wpTypes = NotificationChannelType.values();
-		
+
 		for (int i = 0; i < wpTypes.length; i++) {
 			valueToInsert += wpTypes[i];
 			if (i < wpTypes.length-1)
@@ -1094,13 +1101,17 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 			for (Row<String, String> row : result.getResult()) 
 				for (Column<String> column : row.getColumns()) {
 					String[] channels = column.getStringValue().split(",");
-					NotificationChannelType[] toAdd = new NotificationChannelType[channels.length];		
-					for (int i = 0; i < channels.length; i++) {
-						if (channels[i].compareTo("") != 0)
-							toAdd[i] = (getChannelType(channels[i]));
+					if (channels != null && channels.length == 1 && channels[0].toString().equals("") ) { //it is empty, preference is set to no notification at all
+						toReturn.put(getNotificationType(column.getName()), new NotificationChannelType[0]);
+					} else {
+						NotificationChannelType[] toAdd = new NotificationChannelType[channels.length];		
+						for (int i = 0; i < channels.length; i++) {
+							if (channels[i].compareTo("") != 0) {
+								toAdd[i] = (getChannelType(channels[i]));
+							}
+						}
+						toReturn.put(getNotificationType(column.getName()), toAdd);
 					}
-					toReturn.put(getNotificationType(column.getName()), toAdd);
-
 				}
 		}
 		return toReturn;
@@ -1297,8 +1308,8 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 			m.withRow(cf_Likes, likeid).delete();
 			//delete the column from UserLikes
 			m.withRow(cf_UserLikedFeeds, userid).deleteColumn(likeid);
-			
-			
+
+
 
 			try {
 				m.execute();
@@ -1494,6 +1505,9 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		if (type.compareTo("WP_FOLDER_SHARE") == 0) {
 			return NotificationType.WP_FOLDER_SHARE;
 		}
+		else if (type.compareTo("WP_FOLDER_UNSHARE") == 0) {
+			return NotificationType.WP_FOLDER_UNSHARE;
+		}
 		else if (type.compareTo("WP_FOLDER_RENAMED") == 0) {
 			return NotificationType.WP_FOLDER_RENAMED;
 		}
